import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import QtGraphicalEffects 1.0

MainView {
    // We defint objectName for functional testing purposes
    // (autopilot-qt5)
    objectName: "mainView"
    applicationName: "qreator-touch"
    id: root

    width: units.gu(50)
    height: units.gu(75)

    PageStack {
        id: pageStack
        property real pageSpacing: units.gu(6)

        anchors {
            fill: parent
        }
        
        Component.onCompleted: push(pageRoot)

        Page {
            id: pageRoot
            title: i18n.tr("QR code type")
            visible: false

            Column {
                anchors.fill: parent
                ListItem.Standard {
                    id: itemQrText
                    text: i18n.tr("Text")
                    icon: Qt.resolvedUrl("img/text.png")
                    onClicked: pageStack.push(pageQrText)
                    progression: true
                }
                ListItem.Standard {
                    id: itemQrUrl
                    text: i18n.tr("URL")
                    icon: Qt.resolvedUrl("img/url.png")
                    onClicked: pageStack.push(pageQrUrl)
                    progression: true
                }
                ListItem.Standard {
                    id: itemQrWifi
                    text: i18n.tr("Wifi")
                    icon: Qt.resolvedUrl("img/wifi.png")
                    onClicked: pageStack.push(pageQrWifi)
                    progression: true
                }
            }

            tools: ToolbarActions {
                Action {
                    text: i18n.tr("About")
                    iconSource: Qt.resolvedUrl("img/about.png")
                    onTriggered: pageStack.push(pageAbout)
                }
                Action {
                    text: i18n.tr("History")
                    iconSource: Qt.resolvedUrl("img/history.png")
                    onTriggered: pageStack.push(pageHistory)
                }
                Action {
                    text: i18n.tr("Settings")
                    iconSource: Qt.resolvedUrl("img/settings.png")
                    onTriggered: pageStack.push(pageSettings)
                }
            }
        }

        Page {
            id: pageQrText
            title: i18n.tr("Text QR code")
            visible: false

            Column {
                anchors.centerIn: parent
                spacing: pageStack.pageSpacing

                TextArea {
                     id: textQrCodeText
                     placeholderText: i18n.tr("Type the text to encode")
                     autoSize: true
                     maximumLineCount: 5
                     width: units.gu(33)

                     onTextChanged: {qrcanvastext.requestQrCodePaint(text)}
                 }

                QrCodeCanvas {
                        id: qrcanvastext
                        width: units.gu(33)
                        height: units.gu(33)
                }
            }

        }

        Page {
            id: pageQrUrl
            title: i18n.tr("URL QR code")
            visible: false

            Column {
                anchors.centerIn: parent
                spacing: pageStack.pageSpacing
                    
                TextField {
                        id: textQrCodeUrl
                        width: units.gu(33)
                        placeholderText: i18n.tr("Type the URL to encode")
                        hasClearButton: true

                        onTextChanged: {qrcanvasurl.requestQrCodePaint(text)}
                }

                QrCodeCanvas {
                        id: qrcanvasurl
                        width: units.gu(33)
                        height: units.gu(33)
                }
            }

            //tools: Loader {sourceComponent: qrcodetoolbar}
            //tools: qrcodetoolbar
        }

        Page {
            id: pageQrWifi
            title: i18n.tr("Wireless access QR code")
            visible: false

            ListModel {
                id: wifiSecurity
                ListElement {
                    security: "WPA"
                    index: 0
                }
                ListElement {
                    security: "WEP"
                    index: 1
                }
                ListElement {
                    security: "No security"
                    index: 2
                }
            }

            Column {
                anchors.centerIn: parent
                spacing: units.gu(4)

                Column {
                    spacing: units.gu(2)

                    TextField {
                         id: textQrCodeSsid
                         placeholderText: i18n.tr("Type the wifi network's identifier")
                         hasClearButton: true
                         width: units.gu(33)

                         onTextChanged: {qrcanvaswifi.requestQrCodePaint(text)}
                    }

                    Button {
                        id: selectorSecurity
                                    //property int currencyIndex: 0
                                    //property  TextField input: inputFrom
                                    //text: currencies.getCurrency(currencyIndex)
                                    // open the popover
                        text: i18n.tr("Select security")
                        width: units.gu(33)
                        onClicked: PopupUtils.open(popoverWifiSecurity, selectorSecurity)
                        onTextChanged: {qrcanvaswifi.requestQrCodePaint(text)}
                    }

                    Row {
                        spacing: units.gu(2)

                        TextField {
                             id: textQrCodePassword
                             placeholderText: i18n.tr("Type the wifi network's password")
                             hasClearButton: true
                             echoMode: switchPassword.checked ? TextInput.Normal : TextInput.Password
                             width: units.gu(33) - parent.spacing - switchPassword.width

                             onTextChanged: {qrcanvaswifi.requestQrCodePaint(text)}
                        }

                        Switch {
                            id: switchPassword
                            checked: false

                            //onClicked:
                        }
                    }
                }

                QrCodeCanvas {
                        id: qrcanvaswifi
                        width: units.gu(33)
                        height: units.gu(33)
                }
            }

        }
        
        Page {
            id: pageSettings
            title: i18n.tr("Settings")
            visible: false

            Column {

            }
        }
 
        Page {
            id: pageAbout
            title: i18n.tr("About")
            visible: false

            Column {

            }
        }       

        Page {
            id: pageHistory
            title: i18n.tr("History")
            visible: false

            Column {

            }
        }
        
    }

    Component {
        id: popoverWifiSecurity
        Popover {
            Column {
                    anchors {
                        top: parent.top
                        left: parent.left
                        right: parent.right
                    }
                    // Make sure the Popover doesn't flow off the screen
                    height: units.gu(33) //getHeight()

                    //units.gu(33) //wifiSecurity.count * wifiSecurity.get(0).height //units.gu(33)//root.height

                    function getHeight () {
                        var firstElement = wifiSecurity.get(0);
                        console.log(firstElement.security);
                        return wifiSecurity.count * firstElement.height;
                    }


                    // Header displaying title
                    ListItem.Header {
                        id: header
                        text: i18n.tr("Select security")
                    }
                    // List of security modes
                    ListView {
                        clip: true
                        width: parent.width
                        height: parent.height - header.height
                        model: wifiSecurity
                        delegate: ListItem.Standard {
                            text: security
                            onClicked: {
                                caller.text = security
                                //caller.input.update()
                                hide()
                            }
                        }
                    }
                }
            }
        }


    Component {
        id: qrcodetoolbar
        //Item {
            ToolbarActions {
                        Action {
                            text: i18n.tr("Edit")
                            iconSource: Qt.resolvedUrl("img/about.png")
                            //onTriggered: pageStack.push(pageAbout)
                        }
                        Action {
                            text: i18n.tr("Save")
                            iconSource: Qt.resolvedUrl("img/history.png")
                            //onTriggered: pageStack.push(pageHistory)
                        }
                        Action {
                            text: i18n.tr("Share")
                            iconSource: Qt.resolvedUrl("img/settings.png")
                            //onTriggered: pageStack.push(pageSettings)
                        }
                    }
        //}
    }

}

